 {
          'dsn' => 'dbi:mysql:dbi_sequence',
          'rootpw' => undef,
          'root' => 'root',
          'extended' => 1,
          'state_table' => 'dbix_sequence_state',
          'oracle_home' => undef,
          'release_table' => 'dbix_sequence_release'
        };
